@@ -7,11 +7,12 @@ from . import chicagofswild
 
 class ChicagoFSWildTest(tfds.testing.DatasetBuilderTestCase):
     """Tests for how2sign dataset."""
+
     # TODO(how2sign):
     DATASET_CLASS = chicagofswild.ChicagoFSWild
     SPLITS = {
-        'train': 3,  # Number of fake train example
-        'test': 1,  # Number of fake test example
+        "train": 3,  # Number of fake train example
+        "test": 1,  # Number of fake test example
     }
 
     # If you are calling `download/download_and_extract` with a dict, like:
@@ -21,5 +22,5 @@ class ChicagoFSWildTest(tfds.testing.DatasetBuilderTestCase):
     # DL_EXTRACT_RESULT = {'some_key': 'output_file1.txt', ...}
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     tfds.testing.test_main()
